.. _glossary:

Glossary
========

.. glossary::
    :sorted:

    Endpoint
        The specific ``route`` or URL designated for handling the RPC.

    RPC
        A Remote Procedure Call. See `Wikipedia entry on Remote procedure calls 
        <http://en.wikipedia.org/wiki/Remote_procedure_call>`_

